
# Type: time type




URI: [biolink:TimeType](https://w3id.org/biolink/vocab/TimeType)

|  |  |  |
| --- | --- | --- |
| Parent type | | [Time](types/Time.md) |
| Root (builtin) type | | **XSDTime** |
| Representation | | str |
